==> openmetadata-commons-1.0.0-20130831.155237-83-sources.jar: org/openmetadata/dataset/DiscreteMissingValue.java <==
package org.openmetadata.dataset;



public class DiscreteMissingValue implements MissingValue{

	public enum DISCRETE_OPERATION {EQUALS, NOT_EQUALS};
	private String id;
	private String label = "";
	private DISCRETE_OPERATION discreteOperation = DISCRETE_OPERATION.EQUALS;

	public DiscreteMissingValue(){

	}

	public DiscreteMissingValue(String id){
		this.id = id;
	}

	public DiscreteMissingValue(String value, String label){
		this.id = value;
		this.label = label;
	}

	@Override
	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	@Override
	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	@Override
	public boolean isMissing(Object value) {
		boolean isMissing = false;

		if(discreteOperation.equals(DISCRETE_OPERATION.EQUALS)){
			
			String testCase = value.toString()+" | "+getId();
			
			Double valueDouble = null;
			Double valueMissing = null;
			
			try{
				valueDouble = Double.parseDouble(value.toString());
				valueMissing = Double.parseDouble(getId());
			}
			catch(Exception e){
				//value is string
			}			
			
			if(value instanceof Number){
				Double doubleValue = Double.parseDouble(value.toString());
				Double doubleMissing = Double.parseDouble(getId());
				
				if(doubleValue.toString().trim().equalsIgnoreCase(doubleMissing.toString().trim())){
					isMissing=true;
				}
			}
			else if(valueDouble != null && valueMissing != null){
				if(valueDouble.equals(valueMissing)){
					isMissing = true;
				}
			}
			else if(value.toString().trim().equalsIgnoreCase(getId().trim())){
				isMissing=true;
			}
		}
		else{
			Double valueDouble = null;
			Double valueMissing = null;
			
			try{
				valueDouble = Double.parseDouble(value.toString());
				valueMissing = Double.parseDouble(getId());
			}
			catch(Exception e){
				//value is string
			}			
			
			if(value instanceof Number){
				Double doubleValue = Double.parseDouble(value.toString());
				Double doubleMissing = Double.parseDouble(getId().toString());
				
				if(!doubleValue.toString().trim().equalsIgnoreCase(doubleMissing.toString().trim())){
					isMissing=true;
				}
			}
			else if(valueDouble != null && valueMissing != null){
				if(valueDouble.equals(valueMissing)){
					isMissing = true;
				}
			}
			else if(!value.toString().trim().equalsIgnoreCase(getId().trim())){
				isMissing=true;
			}
		}

		return isMissing;
	}
	
	public DISCRETE_OPERATION getDiscreteOperation() {
		return discreteOperation;
	}
	
	public void setDiscreteOperation(DISCRETE_OPERATION discreteOperation) {
		this.discreteOperation = discreteOperation;
	}
}

==> openmetadata-commons-1.0.0-20131018.123949-84-sources.jar: org/openmetadata/dataset/DiscreteMissingValue.java <==
package org.openmetadata.dataset;



public class DiscreteMissingValue implements MissingValue{

	public enum DISCRETE_OPERATION {EQUALS, NOT_EQUALS};
	private String id;
	private String label = "";
	private DISCRETE_OPERATION discreteOperation = DISCRETE_OPERATION.EQUALS;

	public DiscreteMissingValue(){

	}

	public DiscreteMissingValue(String id){
		this.id = id;
	}

	public DiscreteMissingValue(String value, String label){
		this.id = value;
		this.label = label;
	}

	@Override
	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	@Override
	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	@Override
	public boolean isMissing(Object value) {
		boolean isMissing = false;

		if(discreteOperation.equals(DISCRETE_OPERATION.EQUALS)){
			
			String testCase = value.toString()+" | "+getId();
			
			Double valueDouble = null;
			Double valueMissing = null;
			
			boolean valueIsString = false;
			
			try{
				valueDouble = Double.parseDouble(value.toString());
				valueMissing = Double.parseDouble(getId());
			}
			catch(Exception e){
				valueIsString =  true;
			}			
			
			if(valueIsString){
				value.toString().equalsIgnoreCase(getId());
				isMissing = true;
			}
			else if(value instanceof Number){
				Double doubleValue = Double.parseDouble(value.toString());
				Double doubleMissing = Double.parseDouble(getId());
				
				if(doubleValue.toString().trim().equalsIgnoreCase(doubleMissing.toString().trim())){
					isMissing=true;
				}
			}
			else if(valueDouble != null && valueMissing != null){
				if(valueDouble.equals(valueMissing)){
					isMissing = true;
				}
			}
			else if(value.toString().trim().equalsIgnoreCase(getId().trim())){
				isMissing=true;
			}
		}
		else{
			Double valueDouble = null;
			Double valueMissing = null;
			
			boolean valueIsString = false;
			
			try{
				valueDouble = Double.parseDouble(value.toString());
				valueMissing = Double.parseDouble(getId());
			}
			catch(Exception e){
				valueIsString =  true;
			}			
			
			if(valueIsString){
				value.toString().equalsIgnoreCase(getId());
				isMissing = true;
			}
			else if(value instanceof Number){
				Double doubleValue = Double.parseDouble(value.toString());
				Double doubleMissing = Double.parseDouble(getId().toString());
				
				if(!doubleValue.toString().trim().equalsIgnoreCase(doubleMissing.toString().trim())){
					isMissing=true;
				}
			}
			else if(valueDouble != null && valueMissing != null){
				if(valueDouble.equals(valueMissing)){
					isMissing = true;
				}
			}
			else if(!value.toString().trim().equalsIgnoreCase(getId().trim())){
				isMissing=true;
			}
		}

		return isMissing;
	}
	
	public DISCRETE_OPERATION getDiscreteOperation() {
		return discreteOperation;
	}
	
	public void setDiscreteOperation(DISCRETE_OPERATION discreteOperation) {
		this.discreteOperation = discreteOperation;
	}
}
